# Changelog

All notable changes to this project will be documented in this file.

## 0.0.3

* Reorganized the package structure for better clarity and maintainability.
* Moved testing utilities from `utils` to the new `testing` module.

## 0.0.2

* Refactored the `_vindex_array` method to use slices, reducing the graph size.
* Merged `_vindex_slice` tasks corresponding to the same chunks.

## 0.0.1

* New implementation of the `_vindex_array` method.
* Added the `patched_vindex` method.
